@@ -34,9 +34,12 @@ from .._impl import (
     event_SortField as SortField,
     event_SortOptions as SortOptions,
     event_TemplateEventOrigin as TemplateEventOrigin,
+    event_TimeSeriesChannelAssociation as TimeSeriesChannelAssociation,
     event_UpdateDispositionRequest as UpdateDispositionRequest,
     event_UpdateEvent as UpdateEvent,
     event_UpdateEventRequest as UpdateEventRequest,
+    event_WorkbookDataAssociation as WorkbookDataAssociation,
+    event_WorkbookDataAssociationVisitor as WorkbookDataAssociationVisitor,
     event_WorkbookEventOrigin as WorkbookEventOrigin,
 )
 
@@ -74,9 +77,12 @@ __all__ = [
     'SortField',
     'SortOptions',
     'TemplateEventOrigin',
+    'TimeSeriesChannelAssociation',
     'UpdateDispositionRequest',
     'UpdateEvent',
     'UpdateEventRequest',
+    'WorkbookDataAssociation',
+    'WorkbookDataAssociationVisitor',
     'WorkbookEventOrigin',
     'EventService',
 ]
