@@ -23,8 +23,6 @@ from .._impl import (
     ingest_api_DeprecatedNewCsv as DeprecatedNewCsv,
     ingest_api_DeprecatedNewDataSource as DeprecatedNewDataSource,
     ingest_api_DeprecatedNewDataSourceVisitor as DeprecatedNewDataSourceVisitor,
-    ingest_api_DeprecatedTimestampMetadata as DeprecatedTimestampMetadata,
-    ingest_api_DeprecatedTriggerIngest as DeprecatedTriggerIngest,
     ingest_api_DockerImageSource as DockerImageSource,
     ingest_api_EnvironmentVariable as EnvironmentVariable,
     ingest_api_EpochTimestamp as EpochTimestamp,
@@ -112,7 +110,6 @@ from .._impl import (
     ingest_api_SearchContainerizedExtractorsQueryVisitor as SearchContainerizedExtractorsQueryVisitor,
     ingest_api_SearchContainerizedExtractorsRequest as SearchContainerizedExtractorsRequest,
     ingest_api_SignPartResponse as SignPartResponse,
-    ingest_api_SkipRowsConfig as SkipRowsConfig,
     ingest_api_TagDetails as TagDetails,
     ingest_api_TimeOffsetSpec as TimeOffsetSpec,
     ingest_api_TimeOffsetSpecVisitor as TimeOffsetSpecVisitor,
@@ -120,9 +117,6 @@ from .._impl import (
     ingest_api_TimestampMetadata as TimestampMetadata,
     ingest_api_TimestampType as TimestampType,
     ingest_api_TimestampTypeVisitor as TimestampTypeVisitor,
-    ingest_api_TriggerFileIngest as TriggerFileIngest,
-    ingest_api_TriggerIngest as TriggerIngest,
-    ingest_api_TriggeredIngest as TriggeredIngest,
     ingest_api_UpdateContainerizedExtractorRequest as UpdateContainerizedExtractorRequest,
     ingest_api_UserAndPasswordAuthentication as UserAndPasswordAuthentication,
     ingest_api_UtcTimestamp as UtcTimestamp,
@@ -157,8 +151,6 @@ __all__ = [
     'DeprecatedNewCsv',
     'DeprecatedNewDataSource',
     'DeprecatedNewDataSourceVisitor',
-    'DeprecatedTimestampMetadata',
-    'DeprecatedTriggerIngest',
     'DockerImageSource',
     'EnvironmentVariable',
     'EpochTimestamp',
@@ -245,7 +237,6 @@ __all__ = [
     'SearchContainerizedExtractorsQueryVisitor',
     'SearchContainerizedExtractorsRequest',
     'SignPartResponse',
-    'SkipRowsConfig',
     'TagDetails',
     'TimeOffsetSpec',
     'TimeOffsetSpecVisitor',
@@ -253,9 +244,6 @@ __all__ = [
     'TimestampMetadata',
     'TimestampType',
     'TimestampTypeVisitor',
-    'TriggerFileIngest',
-    'TriggerIngest',
-    'TriggeredIngest',
     'UpdateContainerizedExtractorRequest',
     'UserAndPasswordAuthentication',
     'UtcTimestamp',
