@@ -138,6 +138,7 @@ from .._impl import (
     scout_chartdefinition_api_StalenessVisualisationVisitor as StalenessVisualisationVisitor,
     scout_chartdefinition_api_Threshold as Threshold,
     scout_chartdefinition_api_ThresholdDisconnectedValues as ThresholdDisconnectedValues,
+    scout_chartdefinition_api_ThresholdLatch as ThresholdLatch,
     scout_chartdefinition_api_ThresholdLineStyle as ThresholdLineStyle,
     scout_chartdefinition_api_ThresholdShadingConfig as ThresholdShadingConfig,
     scout_chartdefinition_api_TimeSeriesChartDefinition as TimeSeriesChartDefinition,
@@ -323,6 +324,7 @@ __all__ = [
     'StalenessVisualisationVisitor',
     'Threshold',
     'ThresholdDisconnectedValues',
+    'ThresholdLatch',
     'ThresholdLineStyle',
     'ThresholdShadingConfig',
     'TimeSeriesChartDefinition',
