@@ -15,10 +15,11 @@ from .._impl import (
     scout_rids_api_FunctionLineageRid as FunctionLineageRid,
     scout_rids_api_FunctionRid as FunctionRid,
     scout_rids_api_GroupRid as GroupRid,
+    scout_rids_api_LabelsFilter as LabelsFilter,
     scout_rids_api_MarkingRid as MarkingRid,
     scout_rids_api_NotebookRid as NotebookRid,
     scout_rids_api_PendingReviewAlertState as PendingReviewAlertState,
-    scout_rids_api_ProcedureExecutionRid as ProcedureExecutionRid,
+    scout_rids_api_PropertiesFilter as PropertiesFilter,
     scout_rids_api_SavedViewRid as SavedViewRid,
     scout_rids_api_SnapshotRid as SnapshotRid,
     scout_rids_api_TemplateRid as TemplateRid,
@@ -46,10 +47,11 @@ __all__ = [
     'FunctionLineageRid',
     'FunctionRid',
     'GroupRid',
+    'LabelsFilter',
     'MarkingRid',
     'NotebookRid',
     'PendingReviewAlertState',
-    'ProcedureExecutionRid',
+    'PropertiesFilter',
     'SavedViewRid',
     'SnapshotRid',
     'TemplateRid',
